@@ -6,7 +6,7 @@ context("getOmega")
 # small differences (in 1e-6 or 1e-8 tolerance for eample) that will then accumulate to "big" differences in Omega.
 # This is why these tests are commented out (and used only for development).
 test_that("quantileResiduals works", {
-  expect_equal(quantileResiduals_int(VIX, 1, 1, c(-2, 0.8, 1, 12), StMAR=TRUE)[13], 0.9494652, tolerance=1e-3)
+  expect_equal(quantileResiduals_int(VIX, 1, 1, c(-2, 0.8, 1, 12), model="StMAR")[13], 0.9494652, tolerance=1e-3)
 })
 
 # # getOmega calls other functions to deal with constraints, so they are not tested separately
@@ -18,12 +18,12 @@ test_that("quantileResiduals works", {
 # params13gsr <- c(1.3, 2.2, 1.4, 0.8, 2.4, 4.6, 0.4, 0.25, 0.15, 20) # M1=2, M2=1
 #
 # g_norm <- function(r) cbind(r^2-1, r^3, r^4-3)
-# omega_n11t <- getOmega(VIX, 1, 1, params11t, StMAR=TRUE, g=g_norm, dim_g=3)
+# omega_n11t <- getOmega(VIX, 1, 1, params11t, model="StMAR", g=g_norm, dim_g=3)
 # omega_n12 <- getOmega(VIX, 1, 2, params12, g=g_norm, dim_g=3)
 # omega_n12r <- getOmega(VIX, 1, 2, params12r, restricted=TRUE, g=g_norm, dim_g=3)
-# omega_n23t <- getOmega(VIX, 2, 3, params23t, StMAR=TRUE, g=g_norm, dim_g=3)
-# omega_n23gs <- getOmega(VIX, 1, c(1, 1), params12gs, GStMAR=TRUE, g=g_norm, dim_g=3)
-# omega_n13gsr <- getOmega(VIX, 1, c(2, 1), params13gsr, GStMAR=TRUE, restricted=TRUE, g=g_norm, dim_g=3)
+# omega_n23t <- getOmega(VIX, 2, 3, params23t, model="StMAR", g=g_norm, dim_g=3)
+# omega_n23gs <- getOmega(VIX, 1, c(1, 1), params12gs, model="G-StMAR", g=g_norm, dim_g=3)
+# omega_n13gsr <- getOmega(VIX, 1, c(2, 1), params13gsr, model="G-StMAR", restricted=TRUE, g=g_norm, dim_g=3)
 #
 # test_that("getOmega works for normality tests", {
 #   expect_equal(omega_n11t[2, 2], 52.05743, tolerance=1e-3)
@@ -57,20 +57,20 @@ test_that("quantileResiduals works", {
 #   }
 # }
 #
-# omega_ac1_11t <- getOmega(VIX, 1, 1, params11t, StMAR=TRUE, g=g_ac1, dim_g=1)
-# omega_ac1_12 <- getOmega(VIX, 1, 2, params12, g=g_ac1, dim_g=1)
+# omega_ac1_11t <- getOmega(VIX, 1, 1, params11t, model="StMAR", g=g_ac1, dim_g=1)
+# omega_ac1_12 <- getOmega(VIX, 1, 2, params12, model="GMAR", g=g_ac1, dim_g=1)
 # omega_ac1_12r <- getOmega(VIX, 1, 2, params12r, restricted=TRUE, g=g_ac1, dim_g=1)
-# omega_ac1_23t <- getOmega(VIX, 2, 3, params23t, StMAR=TRUE, g=g_ac1, dim_g=1)
+# omega_ac1_23t <- getOmega(VIX, 2, 3, params23t, model="StMAR", g=g_ac1, dim_g=1)
 #
-# omega_ac3_11t <- getOmega(VIX, 1, 1, params11t, StMAR=TRUE, g=g_ac3, dim_g=3)
+# omega_ac3_11t <- getOmega(VIX, 1, 1, params11t, model="StMAR", g=g_ac3, dim_g=3)
 # omega_ac3_12 <- getOmega(VIX, 1, 2, params12, g=g_ac3, dim_g=3)
 # omega_ac3_12r <- getOmega(VIX, 1, 2, params12r, restricted=TRUE, g=g_ac3, dim_g=3)
-# omega_ac3_23t <- getOmega(VIX, 2, 3, params23t, StMAR=TRUE, g=g_ac3, dim_g=3)
+# omega_ac3_23t <- getOmega(VIX, 2, 3, params23t, model="StMAR", g=g_ac3, dim_g=3)
 #
-# omega_ac1_12gs <- getOmega(VIX, 1, c(1,1), params12gs, GStMAR=TRUE, g=g_ac1, dim_g=1)
-# omega_ac1_13gsr <- getOmega(VIX, 1, c(2,1), params13gsr, GStMAR=TRUE, restricted=TRUE, g=g_ac1, dim_g=1)
-# omega_ac3_12gs <- getOmega(VIX, 1, c(1,1), params12gs, GStMAR=TRUE, g=g_ac3, dim_g=3)
-# omega_ac3_13gsr <- getOmega(VIX, 1, c(2,1), params13gsr, GStMAR=TRUE, restricted=TRUE, g=g_ac3, dim_g=3)
+# omega_ac1_12gs <- getOmega(VIX, 1, c(1,1), params12gs, model="G-StMAR", g=g_ac1, dim_g=1)
+# omega_ac1_13gsr <- getOmega(VIX, 1, c(2,1), params13gsr, model="G-StMAR", restricted=TRUE, g=g_ac1, dim_g=1)
+# omega_ac3_12gs <- getOmega(VIX, 1, c(1,1), params12gs, model="G-StMAR", g=g_ac3, dim_g=3)
+# omega_ac3_13gsr <- getOmega(VIX, 1, c(2,1), params13gsr, model="G-StMAR", restricted=TRUE, g=g_ac3, dim_g=3)
 #
 # test_that("getOmega works for autocorrelation test", {
 #   expect_equal(omega_ac1_12gs[1,1], 31.9099, tolerance=1e-3)
@@ -109,20 +109,20 @@ test_that("quantileResiduals works", {
 #   }
 # }
 #
-# omega_ch1_11t <- getOmega(VIX, 1, 1, params11t, StMAR=TRUE, g=g_ch1, dim_g=1)
+# omega_ch1_11t <- getOmega(VIX, 1, 1, params11t, model="StMAR", g=g_ch1, dim_g=1)
 # omega_ch1_12 <- getOmega(VIX, 1, 2, params12, g=g_ch1, dim_g=1)
 # omega_ch1_12r <- getOmega(VIX, 1, 2, params12r, restricted=TRUE, g=g_ch1, dim_g=1)
-# omega_ch1_23t <- getOmega(VIX, 2, 3, params23t, StMAR=TRUE, g=g_ch1, dim_g=1)
+# omega_ch1_23t <- getOmega(VIX, 2, 3, params23t, model="StMAR", g=g_ch1, dim_g=1)
 #
-# omega_ch3_11t <- getOmega(VIX, 1, 1, params11t, StMAR=TRUE, g=g_ch3, dim_g=3)
+# omega_ch3_11t <- getOmega(VIX, 1, 1, params11t, model="StMAR", g=g_ch3, dim_g=3)
 # omega_ch3_12 <- getOmega(VIX, 1, 2, params12, g=g_ch3, dim_g=3)
 # omega_ch3_12r <- getOmega(VIX, 1, 2, params12r, restricted=TRUE, g=g_ch3, dim_g=3)
-# omega_ch3_23t <- getOmega(VIX, 2, 3, params23t, StMAR=TRUE, g=g_ch3, dim_g=3)
+# omega_ch3_23t <- getOmega(VIX, 2, 3, params23t, model="StMAR", g=g_ch3, dim_g=3)
 #
-# omega_ch1_12gs <- getOmega(VIX, 1, c(1,1), params12gs, GStMAR=TRUE, g=g_ch1, dim_g=1)
-# omega_ch1_13gsr <- getOmega(VIX, 1, c(2,1), params13gsr, GStMAR=TRUE, restricted=TRUE, g=g_ch1, dim_g=1)
-# omega_ch3_12gs <- getOmega(VIX, 1, c(1,1), params12gs, GStMAR=TRUE, g=g_ch3, dim_g=3)
-# omega_ch3_13gsr <- getOmega(VIX, 1, c(2,1), params13gsr, GStMAR=TRUE, restricted=TRUE, g=g_ch3, dim_g=3)
+# omega_ch1_12gs <- getOmega(VIX, 1, c(1,1), params12gs, model="G-StMAR", g=g_ch1, dim_g=1)
+# omega_ch1_13gsr <- getOmega(VIX, 1, c(2,1), params13gsr, model="G-StMAR", restricted=TRUE, g=g_ch1, dim_g=1)
+# omega_ch3_12gs <- getOmega(VIX, 1, c(1,1), params12gs, model="G-StMAR", g=g_ch3, dim_g=3)
+# omega_ch3_13gsr <- getOmega(VIX, 1, c(2,1), params13gsr, model="G-StMAR", restricted=TRUE, g=g_ch3, dim_g=3)
 #
 # test_that("getOmega works for conditional heteroskedasticity tests", {
 #   expect_equal(omega_ch1_12gs[1,1], 16.83635, tolerance=1e-3)
